@@ -12,10 +12,12 @@ from collections import namedtuple
 
 
 class CwPythonWrapper:
-    def __init__(self, botId, botSecret, tick):
-        self.botId = botId,
-        self.botSecret = botSecret,
+    def __init__(self, botId, botSecret, tick, host):
+        self.botId = botId
+        self.botSecret = botSecret
         self.tick = tick
+        self.host = host
+        self.socketIO = SocketIO(self.host, 8080, LoggingNamespace)
         self.socketIO.on("do-identification", self.on_do_identification)
         self.socketIO.on('identification-successful', self.on_identification_successful)
         self.socketIO.on('identification-bot-successful', self.identification_bot_successful)
@@ -23,8 +25,6 @@ class CwPythonWrapper:
         self.socketIO.on('state', self.state)
         self.socketIO.wait()
 
-    socketIO = SocketIO('localhost', 8080, LoggingNamespace)
-
     def on_do_identification(self, *args):
         self.socketIO.emit("identification", "VALID")
 
