@@ -1,4 +1,4 @@
-from models import Bot, Bullet, Pod, Powerup, Map
+from . import Bot, Bullet, Pod, Powerup, Map
 
 
 class State:
